import Taro, { Component } from '@tarojs/taro'
import * as actions from '@actions/user'
import getUserPhone from '@utils/getUserPhone'
import './index.scss'
import { getHFiveDetail } from '@services/user'
import ready from '@utils/ready'
import { reportClient } from '@services/report'
import { connect } from '@tarojs/redux'
import { ROLE_CODE } from '@constants/user'
import { getQrCodeParams } from '@utils/qrcode'
import { getMiniQrcode, savePoint, updatePoint } from '@services/common'
const bgImg = require('@assets/helpgroup/bg.png')

@connect(state => state.user, { ...actions })
export default class Index extends Component {

  state = {
    recordId: undefined, // 埋点ID
    avatarVisible: false,
    phoneVisible: false,
    webViewVisible: false,
    pageInfo: {},
    codeParams: '', // 解析二维码参数
  }

  componentWillUnmount() {
    const { recordId } = this.state
    recordId && updatePoint(recordId)
  }
  // 埋点
  success() {
    const { userInfo: { person } } = this.props

    const router = Taro.getStorageSync('router')
    const firstShare = this.$router.params.firstShare || router.query.firstShare || ""
    const consultant = this.$router.params.consultant || router.query.consultant || ""
    const sharePersonId = this.$router.params.sharePersonId || router.query.sharePersonId || ""
    const { pageInfo } = this.state
    const targetId = pageInfo.drainageId || this.$router.params.id || router.query.id || ""
    savePoint({
      event: 'detail',
      eventType: 'h5',
      propertyName: 'h5活动',
      consultantId: consultant,
      sharePersonId: sharePersonId,
      targetId: targetId,
      data: '{"firstShare":"' + firstShare + '"}'
    }).then(res => {
      this.setState({
        recordId: res.recordId
      })
      console.log('访问记录')
    })
  }
  // 分享好友
  onShareAppMessage = () => {
    const { pageInfo } = this.state
    const currentPage = this.currentPageAndParams().join('?')
    console.log(currentPage)
    return {
      title: pageInfo.shareTitle,
      path: currentPage,
      imageUrl: pageInfo.shareImg
    }
  }
  // // 生成二维码
  // getQRCode() {
  //   const [page, scene] = this.currentPageAndParams()
  //   const payload = { page, scene }
  //   return new Promise((resolve) => {
  //     getMiniQrcode(payload).then(qrCode => {
  //       this.setState({ qrCode }, resolve)
  //     })
  //   })
  // }


  currentPageAndParams() {
    const { userInfo: { person } } = this.props
    const router = Taro.getStorageSync('router')

    const consultant = person.personType == ROLE_CODE['CONSULTANT'] ? person.userId : ""
    const firstShare = this.$router.params.firstShare || person.personId
    const id = this.$router.params.id || router.query.id || ""

    let queryParams = [
      `sharePersonId=${person.personId}`,
      `consultant=${consultant}`,
      `firstShare=${firstShare}`,
      `id=${id}`
    ]


    const res = [
      'pages/project/h5Page',
      queryParams.join('&'),
    ]

    return res
  }
  componentWillMount() {
    ready.queue(() => {
      Taro.showLoading()
      if (this.$router.params.scene) {

        getQrCodeParams(this.$router.params.scene).then((_, codeParams) => {
          this.setState({
            codeParams: codeParams || ''
          })
          // console.log(codeParams, "解析二维码返回值")
        })
      }

      console.log(this.$router, "this.$router")
      const router = Taro.getStorageSync('router')
      console.log(router, "router")
      const hFiveId = this.$router.params.id || router.query.id || ""
      console.log(hFiveId, "hFiveId")
      // h5id 、第一个分享人ID、置业顾问ID、分享人ID
      getHFiveDetail(hFiveId).then(res => {
        Taro.hideLoading()
        if (res.status == 1) {
          this.setState({
            pageInfo: res
          })
        } else {
          Taro.showModal({
            title: '提示',
            content: '活动已下架',
            showCancel: false,
          }).then(() => {
            Taro.switchTab({
              url: '/pages/project/index'
            })
          })
        }
      })
      const { userInfo: { person: { avatarurl, phone } } } = this.props
      console.log(this.props, "this.propsthis.propsthis.props")

      if (avatarurl && avatarurl.indexOf('wx.qlogo.cn') != -1) {
        console.log(avatarurl, "有头像哦~")
        this.setState({
          avatarVisible: false,
        })
        Taro.hideLoading()
        console.log(phone, "phone#########")
        // 头像手机号都有
        if (phone) {

          this.reportClient()
          this.success()
          this.setState({
            phoneVisible: false,
            webViewVisible: true,
          })
        } else {
          this.setState({
            phoneVisible: true,
          })
        }
      } else {
        Taro.hideLoading()
        this.setState({
          avatarVisible: true,
        })
        if (phone) {
          this.setState({
            phoneVisible: false,
          })
        }
      }
    })
  }
  // 授权头像成功
  onAvatarSuccess() {
    this.setState({
      avatarVisible: false,

    })
    const { userInfo: { person: { phone } } } = this.props
    if (phone) {
      this.setState({
        phoneVisible: false,
        webViewVisible: true,
      })
      this.success()
    } else {
      this.setState({
        phoneVisible: true,
      })
    }
    console.log("授权头像成功！")
  }
  // 授权用户信息
  getUserInfo() {
    const { dispatchUpdateUserInfo } = this.props
    const sessionKey = Taro.getStorageSync('sessionKey')

    Taro.showLoading()
    Taro.getUserInfo({
      lang: 'zh_CN',
      success: res => {
        const payload = Object.assign(res, { sessionKey })
        console.log(res, "获取用户信息返回值")
        // 用户信息保存至服务器
        dispatchUpdateUserInfo(payload).then(res => {
          this.onAvatarSuccess();
          console.log('获取用户信息成功')
          Taro.hideLoading()
        })
      },
      fail: (err) => {
        Taro.hideLoading()
        console.error(err)

        Taro.showToast({
          title: '获取用户信息失败',
          icon: 'none'
        })
        return
      }
    })
  }
  // 授权手机号
  getPhoneNumber(e) {
    getUserPhone(e, (phoneNumber) => {
      if (!phoneNumber) {
        Taro.showToast({
          title: '获取手机号失败',
          icon: 'none'
        })
      } else {
        console.log('授权手机成功')
        this.success()
        this.reportClient()
        this.setState({
          phoneVisible: false,
          webViewVisible: true,
        })
      }
    })
  }
  // 报备客户
  reportClient() {

    const router = Taro.getStorageSync('router')
    const consultant = this.$router.params.consultant || router.query.consultant || ""
    const {
      userInfo: { person: { phone, tel, userId } }
    } = this.props
    // debugger
    if (consultant && consultant != userId) {
      const realPhone = phone || tel
      const payload = {
        realtyConsultant: consultant, //报备人 置业顾问
        phone: realPhone,
        showToast: false
      }

      reportClient(payload).then(res => {
        console.log('恭喜您绑定成功')
      }).catch(err => {
        console.error(err)
      })
    }
  }

  renderMaskBanner() {
    const { avatarVisible, phoneVisible, pageInfo } = this.state
    return (
      <View>
        <Image src={pageInfo.middleImg || bgImg} mode='widthFix' className='bg_img'></Image>
        <View className="middle-page">
          {avatarVisible &&
            <View className="content">
              <View className="title">授权头像，围观活动</View>
              <View className="touxiang"><open-data type="userAvatarUrl"></open-data></View>
              <View className="name"><open-data type="userNickName"></open-data></View>
              <Button className="btn" open-type="getUserInfo" lang="zh_CN" onGetUserInfo={this.getUserInfo}>好</Button>
            </View>
          }
          {phoneVisible &&
            <Button className="phone-btn" open-type="getPhoneNumber" lang="zh_CN" onGetphonenumber={this.getPhoneNumber}>点击授权查看详情</Button>
          }
        </View>
      </View>
    )
  }
  render() {
    const { pageInfo, webViewVisible, codeParams } = this.state
    const { userInfo: { person } } = this.props
    const consultant = person.personType == ROLE_CODE['CONSULTANT'] ? person.userId : ""
    const router = Taro.getStorageSync('router')
    const hFiveId = this.$router.params.id || router.query.id || ""
    const webUrlParams = [
      `personId=${person.personId}`,
      `h5id=${hFiveId}`,
      `consultant=${consultant}`,
      `codeParams=${encodeURIComponent(codeParams)}`,
    ].join('&')

    return (
      <Block>
        {this.renderMaskBanner()}
        {webViewVisible && <WebView src={`${pageInfo.h5Address}?${webUrlParams}`} />}
      </Block>
    )
  }
}
